@@ -44,7 +44,7 @@ namespace Amarok
         virtual void paintEvent( TQPaintEvent* )
         {
             TQPainter p( this );
-            parentWidget()->style().tqdrawPrimitive( TQStyle::PE_Splitter, &p, rect(), colorGroup(), TQStyle::Style_Horizontal );
+            parentWidget()->style().drawPrimitive( TQStyle::PE_Splitter, &p, rect(), colorGroup(), TQStyle::Style_Horizontal );
         }
 
         virtual void styleChange( TQStyle& )
@@ -54,7 +54,7 @@ namespace Amarok
 
         virtual void mouseMoveEvent( TQMouseEvent *e )
         {
-            static_cast<BrowserBar*>(TQT_TQWIDGET(parent()))->mouseMovedOverSplitter( e );
+            static_cast<BrowserBar*>(parent())->mouseMovedOverSplitter( e );
         }
     };
 }
@@ -69,10 +69,10 @@ BrowserBar::BrowserBar( TQWidget *parent )
         , m_browserBox( new TQVBox( this ) )
         , m_currentIndex( -1 )
         , m_lastIndex( -1 )
-        , m_mapper( new TQSignalMapper( TQT_TQOBJECT(this) ) )
+        , m_mapper( new TQSignalMapper( this ) )
 {
     m_tabManagementButton = new TQPushButton( SmallIconSet(Amarok::icon( "configure" )), 0, this, "tab_managment_button" );
-    connect (m_tabManagementButton, TQT_SIGNAL(clicked()), TQT_SLOT(showBrowserSelectionMenu()));
+    connect (m_tabManagementButton, TQ_SIGNAL(clicked()), TQ_SLOT(showBrowserSelectionMenu()));
     m_tabManagementButton->setIsMenuButton ( true ); //deprecated, but since I cannot add menu directly to button it is needed.
 
     TQToolTip::add (m_tabManagementButton, i18n("Manage tabs")); 
@@ -105,7 +105,7 @@ BrowserBar::BrowserBar( TQWidget *parent )
     m_divider->hide();
     m_playlistBox->setSpacing( 1 );
 
-    connect( m_mapper, TQT_SIGNAL(mapped( int )), TQT_SLOT(showHideBrowser( int )) );
+    connect( m_mapper, TQ_SIGNAL(mapped( int )), TQ_SLOT(showHideBrowser( int )) );
 
  
 
@@ -255,12 +255,12 @@ BrowserBar::addBrowser( const TQString &identifier, TQWidget *widget, const TQSt
 
     m_tabBar->appendTab( SmallIcon( icon ), id, title, identifier );
     tab = m_tabBar->tab( id );
-    tab->setFocusPolicy( TQ_NoFocus ); //FIXME you can focus on the tab, but they respond to no input!
+    tab->setFocusPolicy( TQWidget::NoFocus ); //FIXME you can focus on the tab, but they respond to no input!
 
     //we use a SignalMapper to show/hide the corresponding browser when tabs are clicked
-    connect( tab, TQT_SIGNAL(clicked()), m_mapper, TQT_SLOT(map()) );
-    m_mapper->setMapping( TQT_TQOBJECT(tab), id );
-    connect( tab, TQT_SIGNAL(initiateDrag ( int ) ), this, TQT_SLOT( showBrowser( int )) );
+    connect( tab, TQ_SIGNAL(clicked()), m_mapper, TQ_SLOT(map()) );
+    m_mapper->setMapping( tab, id );
+    connect( tab, TQ_SIGNAL(initiateDrag ( int ) ), this, TQ_SLOT( showBrowser( int )) );
 
     m_browsers.push_back( widget );
 }
@@ -273,7 +273,7 @@ BrowserBar::removeMediaBrowser( TQWidget *widget )
         m_browsers.erase( it );
     TQWidget *tab;
     tab = m_tabBar->tab( m_browserIds["MediaBrowser"] );
-    m_mapper->removeMappings( TQT_TQOBJECT(tab) );
+    m_mapper->removeMappings( tab );
     m_tabBar->removeTab( m_browserIds["MediaBrowser"] );
 }
 
