@@ -49,7 +49,7 @@ namespace Vis
 
     class SocketNotifier : public TQSocketNotifier
     {
-        Q_OBJECT
+        TQ_OBJECT
   
 
     public:
@@ -61,7 +61,7 @@ namespace Vis
 
     class Selector : public TQListView
     {
-        Q_OBJECT
+        TQ_OBJECT
   
         Selector( TQWidget *parent=0 );
         SocketServer *m_server;
